export function toFixedNumber(a:number,n:number) {
    return parseFloat(a.toFixed(n))
}

export function camelToKebab(str: string) {
    return str.replace(/([a-z])([A-Z])/g, '$1-$2').toLowerCase()
}

export function getRandomKey(length=16) { 
    const chars = 'abcdefghijklmnopqrstuvwxyz0123456789'
    let result = ''
    for (let i = 0; i < length; i++) {
        const randomIndex = Math.floor(Math.random() * chars.length)
        result += chars[randomIndex]
    }
    return result
}

interface OptionItem {
  label: string;
  value: string | number;
}

/**
 * 将枚举类型转换为选项数组
 * @param enumObj 枚举对象
 * @returns 选项数组，label 为枚举的键，value 为枚举的值
 * @example
 * enum Status { Active = '活跃', Inactive = '未激活' }
 * enumToOptions(Status) // [{ label: 'Active', value: '活跃' }, { label: 'Inactive', value: '未激活' }]
 */
export function enumToOptions(enumObj: Record<string, any>): OptionItem[] {
  return Object.entries(enumObj)
    .filter(([key]) => !isNaN(Number(key)) ? false : true)
    .map(([key, value]) => ({
      label: key,
      value: value
    }));
}